summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJim McDonough <jmcd@samba.org>2005-03-16 16:14:04 +0000
committerGerald (Jerry) Carter <jerry@samba.org>2007-10-10 10:56:04 -0500
commite2673ae1c5f942a2197ec5eb68712c382370f6b3 (patch)
treeda1dbd3e48323f405d83318310bf66cf45a07a5e
parent4ba71014d66f488aa58c216651b207a83b7a7d8e (diff)
downloadsamba-e2673ae1c5f942a2197ec5eb68712c382370f6b3.tar.gz
samba-e2673ae1c5f942a2197ec5eb68712c382370f6b3.tar.bz2
samba-e2673ae1c5f942a2197ec5eb68712c382370f6b3.zip
r5831: Along with jra's recent checkins, fix dir/xcopy of empty dirs on OS/2. Bugs
2335, 2337. (This used to be commit 2312ac9d42adcea8576c3923cd5bc8c1851d5375)
-rw-r--r--source3/smbd/trans2.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/smbd/trans2.c b/source3/smbd/trans2.c
index e4e1243d68..ac2a29bd60 100644
--- a/source3/smbd/trans2.c
+++ b/source3/smbd/trans2.c
@@ -1484,13 +1484,13 @@ close_if_end = %d requires_resume_key = %d level = 0x%x, max_data_bytes = %d\n",
}
/*
* If there are no matching entries we must return ERRDOS/ERRbadfile -
* from observation of NT.
*/
if(numentries == 0) {
dptr_close(&dptr_num);
- return ERROR_DOS(ERRDOS,ERRbadfile);
+ return ERROR_DOS(ERRDOS,ERRnofiles);
}
/* At this point pdata points to numentries directory entries. */
@@ -1484,13 +1484,13 @@ close_if_end = %d requires_resume_key = %d level = 0x%x, max_data_bytes = %d\n",
}
/*
- * If there are no matching entries we must return ERRDOS/ERRbadfile -
+ * If there are no matching entries we must return ERRDOS/ERRnofiles -
* from observation of NT.
*/